@@ -208,16 +208,16 @@ static void do_rxpacket(void)
 }
 
 #define DECODEITERA(j)                                                        \
-({                                                                            \
+do {                                                                          \
         if (!(notbitstream & (0x0fc << j)))              /* flag or abort */  \
                 goto flgabrt##j;                                              \
         if ((bitstream & (0x1f8 << j)) == (0xf8 << j))   /* stuffed bit */    \
                 goto stuff##j;                                                \
   enditer##j:;                                                                \
-})
+} while (0)
 
 #define DECODEITERB(j)                                                                 \
-({                                                                                     \
+do {                                                                                   \
   flgabrt##j:                                                                          \
         if (!(notbitstream & (0x1fc << j))) {              /* abort received */        \
                 state = 0;                                                             \
@@ -236,7 +236,7 @@ static void do_rxpacket(void)
         numbits--;                                                                     \
         bitbuf = (bitbuf & ((~0xff) << j)) | ((bitbuf & ~((~0xff) << j)) << 1);        \
         goto enditer##j;                                                               \
-})
+} while (0)
         
 static inline void hdlc_receive(const unsigned char *data, unsigned nrbytes)
 {
@@ -738,6 +738,11 @@ static int diag_start(void)
         } else if (parptr[0] && !strcmp(parptr[0], ioparam_type[0].u.c.combostr[2])) {
                 getparam(diagstate.cfgname, NULL, "audio", ioparams_sim, parptr, params);
                 diagstate.audioio = ioopen_sim(&diagstate.samplerate, IO_RDWR, parptr);
+#ifdef HAVE_ALSA
+	} else if (parptr[0] && !strcmp(parptr[0], ioparam_type[0].u.c.combostr[3])) {
+                getparam(diagstate.cfgname, NULL, "audio", ioparams_alsasoundcard, parptr, params);
+		diagstate.audioio = ioopen_alsasoundcard(&diagstate.samplerate, diagstate.modch->modulate ? IO_RDWR : IO_RDONLY, parptr);
+#endif /* HAVE_ALSA */
         } else {
                 getparam(diagstate.cfgname, NULL, "audio", ioparams_soundcard, parptr, params);
                 diagstate.audioio = ioopen_soundcard(&diagstate.samplerate, diagstate.modch->modulate ? IO_RDWR : IO_RDONLY, parptr);
