@@ -80,6 +80,10 @@ char *alloca ();
 #include <arpa/inet.h>
 #endif
 
+#ifdef HAVE_NET_IF_ARP_H
+#include <net/if_arp.h>
+#endif
+
 #ifdef HAVE_PTY_H
 #include <pty.h>
 #else
@@ -177,14 +181,14 @@ static inline int check_crc_ccitt(const u_int8_t *buffer, int len)
  */
 
 #define ENCODEITERA(j)                         \
-({                                             \
+do {                                           \
         if (!(notbitstream & (0x1f0 << j)))    \
                 goto stuff##j;                 \
   encodeend##j:;                               \
-})
+} while (0)
 
 #define ENCODEITERB(j)                                          \
-({                                                              \
+do {                                                            \
   stuff##j:                                                     \
         bitstream &= ~(0x100 << j);                             \
         bitbuf = (bitbuf & (((2 << j) << numbit) - 1)) |        \
@@ -192,7 +196,7 @@ static inline int check_crc_ccitt(const u_int8_t *buffer, int len)
         numbit++;                                               \
         notbitstream = ~bitstream;                              \
         goto encodeend##j;                                      \
-})
+} while (0)
 
 static void hdlc_encode(struct modemchannel *chan, unsigned char *pkt, unsigned int len)
 {
@@ -309,16 +313,16 @@ static void do_rxpacket(struct modemchannel *chan)
 }
 
 #define DECODEITERA(j)                                                        \
-({                                                                            \
+do {                                                                          \
         if (!(notbitstream & (0x0fc << j)))              /* flag or abort */  \
                 goto flgabrt##j;                                              \
         if ((bitstream & (0x1f8 << j)) == (0xf8 << j))   /* stuffed bit */    \
                 goto stuff##j;                                                \
   enditer##j:;                                                                \
-})
+} while (0)
 
 #define DECODEITERB(j)                                                                 \
-({                                                                                     \
+do {                                                                                   \
   flgabrt##j:                                                                          \
         if (!(notbitstream & (0x1fc << j))) {              /* abort received */        \
                 state = 0;                                                             \
@@ -337,7 +341,7 @@ static void do_rxpacket(struct modemchannel *chan)
         numbits--;                                                                     \
         bitbuf = (bitbuf & ((~0xff) << j)) | ((bitbuf & ~((~0xff) << j)) << 1);        \
         goto enditer##j;                                                               \
-})
+} while (0)
         
 static inline void hdlc_receive(struct modemchannel *chan, const unsigned char *data, unsigned nrbytes)
 {
@@ -874,7 +878,7 @@ void pktinitmkiss(struct modemchannel *chan, const char *params[])
         if (ioctl(fd, SIOCSIFMTU, &ifr) == -1)
                 logerr(MLOG_FATAL, "ioctl: SIOCSIFMTU");
 	if (parsehw(&sax25.sax25_call, params[1])) {
-		sax25.sax25_family = AF_AX25;
+		sax25.sax25_family = ARPHRD_AX25;
 		sax25.sax25_ndigis = 0;
 		memcpy(&ifr.ifr_hwaddr, &sax25, sizeof(ifr.ifr_hwaddr));
 		if (ioctl(fd, SIOCSIFHWADDR, &ifr) == -1)
